C++ Barrier Walks
==========

.. doxygenclass:: RandomWalk
   :members:
   :protected-members:

.. doxygenclass:: BallWalk
   :members:
   :protected-members:

.. doxygenclass:: BarrierWalk
   :members:
   :protected-members: